translate.misc.autoencode.autoencode

Package translate :: Package misc :: Module autoencode :: Class autoencode |
[hide private]
[frames] | no frames]

# Class autoencode

source code

Instance Methods | [hide private]
unicode |
join(self, seq) Return a string which is the concatenation of the strings in the iterable. | source code
__str__(self) str(x) | source code
Inherited from `unicode`: `__add__`, `__contains__`, `__eq__`, `__format__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__repr__`, `__rmod__`, `__rmul__`, `__sizeof__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `format`, `index`, `isalnum`, `isalpha`, `isdecimal`, `isdigit`, `islower`, `isnumeric`, `isspace`, `istitle`, `isupper`, `ljust`, `lower`, `lstrip`, `partition`, `replace`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `unicode` (private): `_formatter_field_name_split`, `_formatter_parser` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods | [hide private]
a new object with type S, a subtype of T |
__new__(newtype, string=`u'````'`, encoding=None, errors=None) |

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(newtype, string=`u'````'`, encoding=None, errors=None) Static Method |
Returns: a new object with type S, a subtype of T Overrides: object.__new__ (inherited documentation)

### join(self, seq) | source code
Return a string which is the concatenation of the strings in the iterable. The separator between elements is S. Returns: unicode Overrides: unicode.join (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)